HostError

Trait HostError 

pub trait HostError: Send {
    // Required methods
    fn to_debug_string(
        &mut self,
        self_: Resource<Error>,
    ) -> impl Future<Output = Result<String>> + Send;
    fn drop(
        &mut self,
        rep: Resource<Error>,
    ) -> impl Future<Output = Result<()>> + Send;
}

Required Methods

fn to_debug_string( &mut self, self_: Resource<Error>, ) -> impl Future<Output = Result<String>> + Send

Returns a string that is suitable to assist humans in debugging this error.

WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.

fn drop( &mut self, rep: Resource<Error>, ) -> impl Future<Output = Result<()>> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: HostError + ?Sized + Send> HostError for &mut _T

Source

fn to_debug_string( &mut self, self_: Resource<Error>, ) -> impl Future<Output = Result<String>> + Send

Returns a string that is suitable to assist humans in debugging this error.

WARNING: The returned string should not be consumed mechanically! It may change across platforms, hosts, or other implementation details. Parsing this string is a major platform-compatibility hazard.

Source

async fn drop(&mut self, rep: Resource<Error>) -> Result<()>

Implementors